using System;
using System.Configuration;

/// <summary>
/// Summary description for PINsafeSettings
/// </summary>
public class PINsafeSettings
{
	// Server settings
	private bool ssl;
	private string server;
	private int port;
	private string context;
	private string secret;
	private bool showPassword;
	private bool showTURing;
	private bool showMessage;
	private bool acceptSelfSigned;
	private bool allowNonPINsafeUsers;
	private string cookieSecret;
	private long idleTimeSecs;

	public PINsafeSettings(bool autoLoad)
	{
		if (autoLoad)
		{
			LoadSettings();
		}
	}

	public PINsafeSettings() : this(true) { }

	public bool Ssl
	{
		get { return ssl; }
		set { ssl = value; }
	}

	public string Server
	{
		get { return server; }
		set { server = value; }
	}

	public int Port
	{
		get { return port; }
		set { port = value; }
	}

	public string Context
	{
		get { return context; }
		set { context = value; }
	}

	public string Secret
	{
		get { return secret; }
		set { secret = value; }
	}

	public bool ShowPassword
	{
		get { return showPassword; }
		set { showPassword = value; }
	}

	public bool ShowTURing
	{
		get { return showTURing; }
		set { showTURing = value; }
	}

	public bool ShowMessage
	{
		get { return showMessage; }
		set { showMessage = value; }
	}

	public bool AcceptSelfSigned
	{
		get { return acceptSelfSigned; }
		set { acceptSelfSigned = value; }
	}

	public bool AllowNonPINsafeUsers
	{
		get { return allowNonPINsafeUsers; }
		set { allowNonPINsafeUsers = value; }
	}

	public string CookieSecret
	{
		get { return cookieSecret; }
		set { cookieSecret = value; }
	}

	public long IdleTimeSecs
	{
		get { return idleTimeSecs; }
		set { idleTimeSecs = value; }
	}

	public void LoadSettings()
	{
		Server = ConfigurationManager.AppSettings["PINsafeServer"];
		String sPort = ConfigurationManager.AppSettings["PINsafePort"];
		Context = ConfigurationManager.AppSettings["PINsafeContext"];
		Secret = ConfigurationManager.AppSettings["PINsafeSecret"];
		String sSsl = ConfigurationManager.AppSettings["PINsafeSecure"];
		String showPw = ConfigurationManager.AppSettings["PINsafePassword"];
		String showImg = ConfigurationManager.AppSettings["PINsafeImage"];
		String showMsg = ConfigurationManager.AppSettings["PINsafeMessage"];
		String allowSelfSigned = ConfigurationManager.AppSettings["PINsafeAcceptSelfSigned"];
		String nonPINsafeUsers = ConfigurationManager.AppSettings["AllowNonPINsafeUsers"];
		cookieSecret = ConfigurationManager.AppSettings["PINsafeCookieSecret"];
		String sIdleTimeSecs = ConfigurationManager.AppSettings["PINsafeIdleTimeSecs"];
		if (sSsl == null || sSsl.Equals(""))
		{
			Ssl = false;
		}
		else
		{
			if (!Boolean.TryParse(sSsl, out ssl))
			{
				Ssl = false;
			}
		}
		if (sPort == null || sPort.Equals(""))
		{
			Port = (Ssl ? 8443 : 8080);
		}
		else
		{
			if (!Int32.TryParse(sPort, out port))
			{
				Port = (Ssl ? 8443 : 8080);
			}
		}
		if (!Boolean.TryParse(showPw, out showPassword))
		{
			ShowPassword = true;
		}
		if (!Boolean.TryParse(showImg, out showTURing))
		{
			ShowTURing = true;
		}
		if (!Boolean.TryParse(showMsg, out showMessage))
		{
			ShowMessage = false;
		}
		if (!Boolean.TryParse(allowSelfSigned, out acceptSelfSigned))
		{
			AcceptSelfSigned = false;
		}
		if (!Boolean.TryParse(nonPINsafeUsers, out allowNonPINsafeUsers))
		{
			allowNonPINsafeUsers = false;
		}
		if (!long.TryParse(sIdleTimeSecs, out idleTimeSecs))
		{
			idleTimeSecs = 300; // Default 5 minutes.
		}
	}
}
